@@ -125,10 +125,10 @@ func evaluateSequence(cmd *cobra.Command, args []string) (cmdError error) {
 	if err != nil {
 		return err
 	}
-
 	streamEvaluator := yqlib.NewStreamEvaluator()
 
 	if frontMatter != "" {
+		yqlib.GetLogger().Debug("using front matter handler")
 		frontMatterHandler := yqlib.NewFrontMatterHandler(args[firstFileIndex])
 		err = frontMatterHandler.Split()
 		if err != nil {
@@ -143,26 +143,18 @@ func evaluateSequence(cmd *cobra.Command, args []string) (cmdError error) {
 		}
 		defer frontMatterHandler.CleanUp()
 	}
+	expression, args := processArgs(pipingStdIn, args)
 
 	switch len(args) {
 	case 0:
-		if pipingStdIn {
-			err = streamEvaluator.EvaluateFiles(processExpression(""), []string{"-"}, printer, leadingContentPreProcessing, decoder)
+		if nullInput {
+			err = streamEvaluator.EvaluateNew(processExpression(expression), printer, "")
 		} else {
 			cmd.Println(cmd.UsageString())
 			return nil
 		}
-	case 1:
-		if nullInput {
-			err = streamEvaluator.EvaluateNew(processExpression(args[0]), printer, "")
-		} else if pipingStdIn && args[0] != "-" && !maybeFile(args[0]) {
-			// must have given a single expression and piping input from stdin
-			err = streamEvaluator.EvaluateFiles(processExpression(args[0]), []string{"-"}, printer, leadingContentPreProcessing, decoder)
-		} else {
-			err = streamEvaluator.EvaluateFiles(processExpression(""), []string{args[0]}, printer, leadingContentPreProcessing, decoder)
-		}
 	default:
-		err = streamEvaluator.EvaluateFiles(processExpression(args[0]), args[1:], printer, leadingContentPreProcessing, decoder)
+		err = streamEvaluator.EvaluateFiles(processExpression(expression), args, printer, leadingContentPreProcessing, decoder)
 	}
 	completedSuccessfully = err == nil
 
