@@ -7,6 +7,7 @@ import (
 
 	"github.com/mikefarah/yq/v4/pkg/yqlib"
 	"github.com/spf13/cobra"
+	"gopkg.in/op/go-logging.v1"
 )
 
 func initCommand(cmd *cobra.Command, args []string) (firstFileIndex int, err error) {
@@ -51,9 +52,12 @@ func configureDecoder() (yqlib.Decoder, error) {
 		return nil, err
 	}
 	switch yqlibInputFormat {
-	case yqlib.XmlInputFormat:
-		return yqlib.NewXmlDecoder(xmlAttributePrefix, xmlContentName), nil
+	case yqlib.XMLInputFormat:
+		return yqlib.NewXMLDecoder(xmlAttributePrefix, xmlContentName), nil
+	case yqlib.PropertiesInputFormat:
+		return yqlib.NewPropertiesDecoder(), nil
 	}
+
 	return yqlib.NewYamlDecoder(), nil
 }
 
@@ -76,18 +80,18 @@ func configurePrinterWriter(format yqlib.PrinterOutputFormat, out io.Writer) (yq
 
 func configureEncoder(format yqlib.PrinterOutputFormat) yqlib.Encoder {
 	switch format {
-	case yqlib.JsonOutputFormat:
-		return yqlib.NewJsonEncoder(indent)
+	case yqlib.JSONOutputFormat:
+		return yqlib.NewJONEncoder(indent)
 	case yqlib.PropsOutputFormat:
 		return yqlib.NewPropertiesEncoder()
-	case yqlib.CsvOutputFormat:
+	case yqlib.CSVOutputFormat:
 		return yqlib.NewCsvEncoder(',')
-	case yqlib.TsvOutputFormat:
+	case yqlib.TSVOutputFormat:
 		return yqlib.NewCsvEncoder('\t')
 	case yqlib.YamlOutputFormat:
 		return yqlib.NewYamlEncoder(indent, colorsEnabled, !noDocSeparators, unwrapScalar)
-	case yqlib.XmlOutputFormat:
-		return yqlib.NewXmlEncoder(indent, xmlAttributePrefix, xmlContentName)
+	case yqlib.XMLOutputFormat:
+		return yqlib.NewXMLEncoder(indent, xmlAttributePrefix, xmlContentName)
 	}
 	panic("invalid encoder")
 }
@@ -98,6 +102,45 @@ func configureEncoder(format yqlib.PrinterOutputFormat) yqlib.Encoder {
 // without this - yq detects there is stdin (thanks githubactions),
 // then tries to parse the filename as an expression
 func maybeFile(str string) bool {
-	_, err := os.Stat(str) // #nosec
-	return err == nil
+	yqlib.GetLogger().Debugf("checking '%v' is a file", str)
+	stat, err := os.Stat(str) // #nosec
+	result := err == nil && !stat.IsDir()
+	if yqlib.GetLogger().IsEnabledFor(logging.DEBUG) {
+		if err != nil {
+			yqlib.GetLogger().Debugf("error: %v", err)
+		} else {
+			yqlib.GetLogger().Debugf("error: %v, dir: %v", err, stat.IsDir())
+		}
+		yqlib.GetLogger().Debugf("result: %v", result)
+	}
+	return result
+}
+
+func processStdInArgs(pipingStdin bool, args []string) []string {
+	if !pipingStdin {
+		return args
+	}
+
+	for _, arg := range args {
+		if arg == "-" {
+			return args
+		}
+	}
+	yqlib.GetLogger().Debugf("missing '-', adding it to the end")
+
+	// we're piping from stdin, but there's no '-' arg
+	// lets add one to the end
+	return append(args, "-")
+}
+
+func processArgs(pipingStdin bool, originalArgs []string) (string, []string) {
+	args := processStdInArgs(pipingStdin, originalArgs)
+	yqlib.GetLogger().Debugf("processed args: %v", args)
+	expression := forceExpression
+	if expression == "" && len(args) > 0 && args[0] != "-" && !maybeFile(args[0]) {
+		yqlib.GetLogger().Debug("assuming expression is '%v'", args[0])
+		expression = args[0]
+		args = args[1:]
+	}
+	return expression, args
 }
