@@ -2,7 +2,6 @@ package yqlib
 
 import (
 	"encoding/xml"
-	"fmt"
 	"io"
 	"strings"
 	"unicode"
@@ -11,24 +10,6 @@ import (
 	yaml "gopkg.in/yaml.v3"
 )
 
-type InputFormat uint
-
-const (
-	YamlInputFormat = 1 << iota
-	XmlInputFormat
-)
-
-func InputFormatFromString(format string) (InputFormat, error) {
-	switch format {
-	case "yaml", "y":
-		return YamlInputFormat, nil
-	case "xml", "x":
-		return XmlInputFormat, nil
-	default:
-		return 0, fmt.Errorf("unknown format '%v' please use [yaml|xml]", format)
-	}
-}
-
 type xmlDecoder struct {
 	reader          io.Reader
 	attributePrefix string
@@ -36,7 +17,7 @@ type xmlDecoder struct {
 	finished        bool
 }
 
-func NewXmlDecoder(attributePrefix string, contentName string) Decoder {
+func NewXMLDecoder(attributePrefix string, contentName string) Decoder {
 	if contentName == "" {
 		contentName = "content"
 	}
@@ -126,6 +107,9 @@ func (dec *xmlDecoder) convertToYamlNode(n *xmlNode) (*yaml.Node, error) {
 		return dec.createMap(n)
 	}
 	scalar := createScalarNode(n.Data, n.Data)
+	if n.Data == "" {
+		scalar = createScalarNode(nil, "")
+	}
 	log.Debug("scalar headC: %v, footC: %v", n.HeadComment, n.FootComment)
 	scalar.HeadComment = dec.processComment(n.HeadComment)
 	scalar.LineComment = dec.processComment(n.LineComment)
@@ -140,7 +124,7 @@ func (dec *xmlDecoder) Decode(rootYamlNode *yaml.Node) error {
 	}
 	root := &xmlNode{}
 	// cant use xj - it doesn't keep map order.
-	err := dec.decodeXml(root)
+	err := dec.decodeXML(root)
 
 	if err != nil {
 		return err
@@ -149,6 +133,9 @@ func (dec *xmlDecoder) Decode(rootYamlNode *yaml.Node) error {
 
 	if err != nil {
 		return err
+	} else if firstNode.Tag == "!!null" {
+		dec.finished = true
+		return io.EOF
 	}
 	rootYamlNode.Kind = yaml.DocumentNode
 	rootYamlNode.Content = []*yaml.Node{firstNode}
@@ -200,7 +187,7 @@ type element struct {
 // this code is heavily based on https://github.com/basgys/goxml2json
 // main changes are to decode into a structure that preserves the original order
 // of the map keys.
-func (dec *xmlDecoder) decodeXml(root *xmlNode) error {
+func (dec *xmlDecoder) decodeXML(root *xmlNode) error {
 	xmlDec := xml.NewDecoder(dec.reader)
 
 	// That will convert the charset if the provided XML is non-UTF-8
