@@ -8,7 +8,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		description: "Set line comment",
 		document:    `a: cat`,
-		expression:  `.a lineComment="single"`,
+		expression:  `.a line_comment="single"`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat # single\n",
 		},
@@ -16,7 +16,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		skipDoc:    true,
 		document:   "a: cat\nb: dog",
-		expression: `.a lineComment=.b`,
+		expression: `.a line_comment=.b`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat # dog\nb: dog\n",
 		},
@@ -24,7 +24,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		skipDoc:    true,
 		document:   "a: cat\n---\na: dog",
-		expression: `.a lineComment |= documentIndex`,
+		expression: `.a line_comment |= documentIndex`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat # 0\n",
 			"D1, P[], (doc)::a: dog # 1\n",
@@ -33,7 +33,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		description: "Use update assign to perform relative updates",
 		document:    "a: cat\nb: dog",
-		expression:  `.. lineComment |= .`,
+		expression:  `.. line_comment |= .`,
 		expected: []string{
 			"D0, P[], (!!map)::a: cat # cat\nb: dog # dog\n",
 		},
@@ -49,7 +49,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		description: "Set head comment",
 		document:    `a: cat`,
-		expression:  `. headComment="single"`,
+		expression:  `. head_comment="single"`,
 		expected: []string{
 			"D0, P[], (doc)::# single\n\na: cat\n",
 		},
@@ -57,7 +57,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		description: "Set foot comment, using an expression",
 		document:    `a: cat`,
-		expression:  `. footComment=.a`,
+		expression:  `. foot_comment=.a`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat\n\n# cat\n",
 		},
@@ -65,7 +65,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		skipDoc:    true,
 		document:   `a: cat`,
-		expression: `. footComment=.b.d`,
+		expression: `. foot_comment=.b.d`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat\n",
 		},
@@ -73,7 +73,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		skipDoc:    true,
 		document:   `a: cat`,
-		expression: `. footComment|=.b.d`,
+		expression: `. foot_comment|=.b.d`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat\n",
 		},
@@ -81,7 +81,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		description: "Remove comment",
 		document:    "a: cat # comment\nb: dog # leave this",
-		expression:  `.a lineComment=""`,
+		expression:  `.a line_comment=""`,
 		expected: []string{
 			"D0, P[], (doc)::a: cat\nb: dog # leave this\n",
 		},
@@ -98,7 +98,7 @@ var commentOperatorScenarios = []expressionScenario{
 	{
 		description: "Get line comment",
 		document:    "# welcome!\n\na: cat # meow\n\n# have a great day",
-		expression:  `.a | lineComment`,
+		expression:  `.a | line_comment`,
 		expected: []string{
 			"D0, P[a], (!!str)::meow\n",
 		},
@@ -107,7 +107,7 @@ var commentOperatorScenarios = []expressionScenario{
 		description:           "Get head comment",
 		dontFormatInputForDoc: true,
 		document:              "# welcome!\n\na: cat # meow\n\n# have a great day",
-		expression:            `. | headComment`,
+		expression:            `. | head_comment`,
 		expected: []string{
 			"D0, P[], (!!str)::welcome!\n",
 		},
@@ -116,7 +116,7 @@ var commentOperatorScenarios = []expressionScenario{
 		description:           "Head comment with document split",
 		dontFormatInputForDoc: true,
 		document:              "# welcome!\n---\n# bob\na: cat # meow\n\n# have a great day",
-		expression:            `headComment`,
+		expression:            `head_comment`,
 		expected: []string{
 			"D0, P[], (!!str)::welcome!\nbob\n",
 		},
@@ -125,7 +125,7 @@ var commentOperatorScenarios = []expressionScenario{
 		description:           "Get foot comment",
 		dontFormatInputForDoc: true,
 		document:              "# welcome!\n\na: cat # meow\n\n# have a great day\n# no really",
-		expression:            `. | footComment`,
+		expression:            `. | foot_comment`,
 		expected: []string{
 			"D0, P[], (!!str)::have a great day\nno really\n",
 		},
