@@ -8,7 +8,7 @@ var documentIndexScenarios = []expressionScenario{
 	{
 		description: "Retrieve a document index",
 		document:    "a: cat\n---\na: frog\n",
-		expression:  `.a | documentIndex`,
+		expression:  `.a | document_index`,
 		expected: []string{
 			"D0, P[a], (!!int)::0\n",
 			"D1, P[a], (!!int)::1\n",
@@ -26,7 +26,7 @@ var documentIndexScenarios = []expressionScenario{
 	{
 		description: "Filter by document index",
 		document:    "a: cat\n---\na: frog\n",
-		expression:  `select(documentIndex == 1)`,
+		expression:  `select(document_index == 1)`,
 		expected: []string{
 			"D1, P[], (doc)::a: frog\n",
 		},
@@ -42,7 +42,7 @@ var documentIndexScenarios = []expressionScenario{
 	{
 		description: "Print Document Index with matches",
 		document:    "a: cat\n---\na: frog\n",
-		expression:  `.a | ({"match": ., "doc": documentIndex})`,
+		expression:  `.a | ({"match": ., "doc": document_index})`,
 		expected: []string{
 			"D0, P[], (!!map)::match: cat\ndoc: 0\n",
 			"D0, P[], (!!map)::match: frog\ndoc: 1\n",
